@@ -1,18 +1,15 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 from __future__ import annotations
 
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, List, Optional
+from typing import Dict, Final, List, Optional
 
 from ycontract import contract
 
 from exclock.sound_player import Player
 from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
-DEFAULT_TITLE = 'ExClock'
+DEFAULT_TITLE: Final[str] = 'ExClock'
 
 
 def inner_str(s: str, d: dict) -> str:
@@ -74,7 +71,7 @@ class ClockTimer:
         return {sec: self.sounds[sec] for sec in sorted(self.sounds)}
 
     @contract(lambda count: count >= 0)
-    def run_once(self, count: int) -> None:
+    def run_once(self, count: int, show_message: bool) -> None:
         sounds = self.sorted_sounds
 
         ps = []
@@ -87,19 +84,21 @@ class ClockTimer:
                 title=self.title,
                 message=message,
                 spend_sec=spend_sec,
-                is_first=sec == 0 and count == 1)
+                is_first=sec == 0 and count == 1,
+                show_message=show_message,
+            )
 
             ps.append(sound.play())
 
-    def run(self) -> None:
+    def run(self, *, show_message: bool) -> None:
         count = 1
         if isinstance(self.loop, int):
             for _ in range(self.loop):
-                self.run_once(count=count)
+                self.run_once(count=count, show_message=show_message)
                 count += 1
         else:
             while True:
-                self.run_once(count=count)
+                self.run_once(count=count, show_message=show_message)
                 count += 1
 
     @classmethod
