@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 import optparse
 from datetime import datetime
 from os import getenv
@@ -70,7 +67,13 @@ def main(opt: optparse.Values, args: List[str]) -> None:
             exit(1)
 
         message = f'Specified time is passed(sec={spend_sec}).'
-        notify_all(title='⏰ Exclock ⏰', message=message, spend_sec=spend_sec, is_first=False)
+        notify_all(
+            title='⏰ Exclock ⏰',
+            message=message,
+            spend_sec=spend_sec,
+            is_first=False,
+            show_message=False,
+        )
 
         p = Player(ring_sound_filename)
         p.play()
